/* Automatically generated file, do not edit */
#ifndef _h_emacs_c
#define _h_emacs_c
libedit_private el_action_t	em_delete_or_list (EditLine *, wint_t);
libedit_private el_action_t	em_delete_next_word (EditLine *, wint_t);
libedit_private el_action_t	em_yank (EditLine *, wint_t);
libedit_private el_action_t	em_kill_line (EditLine *, wint_t);
libedit_private el_action_t	em_kill_region (EditLine *, wint_t);
libedit_private el_action_t	em_copy_region (EditLine *, wint_t);
libedit_private el_action_t	em_gosmacs_transpose (EditLine *, wint_t);
libedit_private el_action_t	em_next_word (EditLine *, wint_t);
libedit_private el_action_t	em_upper_case (EditLine *, wint_t);
libedit_private el_action_t	em_capitol_case (EditLine *, wint_t);
libedit_private el_action_t	em_lower_case (EditLine *, wint_t);
libedit_private el_action_t	em_set_mark (EditLine *, wint_t);
libedit_private el_action_t	em_exchange_mark (EditLine *, wint_t);
libedit_private el_action_t	em_universal_argument (EditLine *, wint_t);
libedit_private el_action_t	em_meta_next (EditLine *, wint_t);
libedit_private el_action_t	em_toggle_overwrite (EditLine *, wint_t);
libedit_private el_action_t	em_copy_prev_word (EditLine *, wint_t);
libedit_private el_action_t	em_inc_search_next (EditLine *, wint_t);
libedit_private el_action_t	em_inc_search_prev (EditLine *, wint_t);
libedit_private el_action_t	em_delete_prev_char (EditLine *, wint_t);
#endif /* _h_emacs_c */
